@@ -175,6 +175,29 @@ def smsCustomerRegister():
                 ]
                 )
             )
+    data["data"]["data"]["contacts"] = [
+        {
+            "viewers_contact_type": "Mobile",
+            "viewers_contact_content": data["data"]["data"].get(["phone"])
+            },
+        {
+            "viewers_contact_type": "Email",
+            "viewers_contact_content": data["data"]["data"].get(["mail"])
+            }
+        ]
+    del(data["data"]["data"]["phone"])
+    del(data["data"]["data"]["mail"])
+
+    data["data"]["data"]["addresses"] = [
+        {
+            "viewers_address_type": "Customer address",
+            "viewers_address_address": data["data"]["data"].get(["rue"]),
+            "viewers_address_streetname": data["data"]["data"].get(["rue"]),
+            "viewers_address_city": data["data"]["data"].get(["ville"]),
+        },
+        ]
+    del(data["data"]["data"]["rue"])
+    del(data["data"]["data"]["ville"])
     data = json.dumps(data)
     response = requests.post(
         '{uri}/customer/update'.format(uri=SMS_URI),
